@@ -2,11 +2,13 @@
 #define _EOG_IMAGE_PRIVATE_H_
 
 #include <libgnomevfs/gnome-vfs-file-size.h>
-#if HAVE_EXIF
+#ifdef HAVE_EXIF
 #include <libexif/exif-data.h>
 #endif
 #include "eog-image.h"
-
+#ifdef HAVE_LCMS
+#include <lcms.h>
+#endif
 
 typedef enum {
 	EOG_IMAGE_STATUS_UNKNOWN,
@@ -17,7 +19,6 @@ typedef enum {
  
 struct _EogImagePrivate {
 	GnomeVFSURI *uri;
-	EogImageLoadMode mode;
 	EogImageStatus status;
 
 	GdkPixbuf *image;
@@ -26,18 +27,23 @@ struct _EogImagePrivate {
 	gint width;
 	gint height;
 	GnomeVFSFileSize bytes;
+	GnomeVFSMonitorHandle *monitor_handle;
+	gpointer toclean;
 	char *file_type;
 
 	guchar  *exif_chunk; /* holds EXIF raw data */
 	guint    exif_chunk_len;
 	guchar  *iptc_chunk; /* holds IPTC raw data */
 	guint    iptc_chunk_len;
-#if HAVE_EXIF
+#ifdef HAVE_EXIF
 	ExifData *exif;      /* this is mutual exclusive to exif_chunk. Only 
 			      * either of these are not NULL:
 			      */
 #endif
-	
+#ifdef HAVE_LCMS
+	cmsHPROFILE profile;
+#endif
+
 	gint thumbnail_id;
 	
 	gboolean modified;
@@ -58,6 +64,8 @@ struct _EogImagePrivate {
 	GList *undo_stack;
 	/* composition of all applied transformations */
 	EogTransform *trans;
+
+	guint data_ref_count;
 };
 
 
